@@ -1,10 +1,9 @@
 import wave
 import os
-from formatConvert.wav_pcm import pcm2wav,wav2pcm,get_data_array
+from formatConvert.wav_pcm import get_data_array
 import  numpy as np
-import math
 from moviepy.editor import AudioFileClip
-
+from commFunction import get_rms,get_ave_rms,get_one_channel_data,get_file_duration
 
 
 def get_wav_from_mp4(mp4file):
@@ -26,21 +25,6 @@ def get_wav_from_mp4(mp4file):
     return newFileName
 
 
-def get_rms(records):
-    '''
-    Parameters
-    ----------
-    records
-
-    Returns
-    -------
-    '''
-    #return math.sqrt(sum([x * x for x in records])/len(records))
-    data = records.astype(np.float32).tolist()
-    rms = math.sqrt(sum([(x/32767) * (x/32767) for x in data])/len(data))
-    dBrmsValue = 20*math.log10(rms + 1.0E-6)
-    return dBrmsValue
-
 def isSlience(Filename =None):
     """
     Parameters
@@ -96,10 +80,42 @@ def audioFormat(wavFileName=None):
     refChannel,refsamWidth,refsamplerate,refframeCount = wavf.getnchannels(),wavf.getsampwidth(),wavf.getframerate(),wavf.getnframes()
     return refChannel,refsamWidth*8,refsamplerate,refframeCount
 
+def get_rms_level(wavFileName=None,rmsMode='total',section=None):
+    """
+    wavFileName：输入文件 wav，mp4
+    Returns
+    -------
+    refChannel:通道数
+    refsamWidth：比特位 2代表16bit
+    refsamplerate：采样率
+    refframeCount：样点数
+    """
+    suffix = os.path.splitext(wavFileName)[-1]
+    if suffix != '.wav':
+        raise TypeError('wrong format! not wav file!' + str(suffix))
+
+    lenth,fs = get_file_duration(wavFileName)
+    data = get_one_channel_data(wavFileName)
+    if section == None:
+        startTime = 0
+        endTime = lenth
+    else:
+        startTime = section[0]
+        endTime = section[1]
+    if startTime > lenth or startTime > endTime:
+        raise TypeError('start point is larger than the file lenth :' + str(suffix))
+    if endTime > lenth:
+        endTime = lenth
+    curdata = data[startTime*fs:endTime*fs]
+    if rmsMode == 'total':
+        return get_rms(curdata)
+    if rmsMode == 'average':
+        return get_ave_rms(curdata)
+    return None
 
 
 
 if __name__ == '__main__':
     ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.pcm'
-    print(isSlience(ref))
+    print(get_rms_level(ref))
     #print(audioFormat(ref))
\ No newline at end of file
