@@ -21,8 +21,7 @@ from .AEC_EVALUATION.ERLE_ETSIMATION import cal_erle
 from .FUNCTION.audioFunction import isSlience,audioFormat
 from .AEC_MOS.aecmos import cal_aec_mos
 from .MOS_INFER.run_predict import cal_mos_infer
-from .MOS_INFER.NISQA_model import *
-from .MOS_INFER.NISQA_lib import *
+from .Noise_Suppression.noiseFuction import  cal_noise_Supp
 from operator import methodcaller
 from .computeAudioQuality.mainProcess import computeAudioQuality
 
@@ -30,11 +29,11 @@ from ctypes import  *
 
 def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFile=None,aecCaliFile=None,outFile=None,noiseFile=None,samplerate=16000,
                           bitwidth=2,channel=1,refOffset=0,testOffset=0,maxComNLevel =-48.0,speechPauseLevel=-35.0,audioType=0,
-                          aecStartPoint=0,aecTargetType=0,aecScenario=0):
+                          aecStartPoint=0,aecTargetType=0,aecScenario=0,rmsCalsection=None):
     """
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/
                     TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA/AGCDELAY/MATCHAEC/
-                    ELRE/SLIENCE/FORMAT/AECMOS/AIMOS，必选项
+                    ELRE/SLIENCE/FORMAT/AECMOS/AIMOS/TRMS/ARMS/NOISE，必选项
     # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
     # POLQA 窄带模式  8k  超宽带模式 48k ；WAV/PCM输入 ；双端输入：ref、test；时长 < 20s；
@@ -56,6 +55,9 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     # FORMAT 无采样率限制 WAV/MP4输入;单端输入：test；无时间长度要求；
     # AECMOS 无采样率限制 WAV/PCM输入 ；三端输入：mic,ref、test；无时间长度要求；
     # AIMOS 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
+    # TRMS 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
+    # ARMS 无采样率限制 WAV/PCM输入 ；单端输入：test；无时间长度要求；
+    # NOISE 无采样率限制 WAV/PCM输入 ；双端输入：ref、test；无时间长度要求；
     不同指标输入有不同的采样率要求，如果传入的文件不符合该指标的要求，会自动变采样到合法的区间
     :param testFile: 被测文件，必选项
     :param refFile:  参考文件，可选项，全参考指标必选，比如POLQA/PESQ/PEAQ
@@ -75,6 +77,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     :param aecStartPoint  计算AECMOS，选择从第几秒开始计算
     :param aecTargetType  0:Chiness 1:English 2:Single Digit 3:Music  计算MATCHAEC/ELRE
     :param aecScenario 计算aec mos专用     0:'doubletalk_with_movement', 1:'doubletalk', 2:'farend_singletalk_with_movement', 3:'farend_singletalk', 4:'nearend_singletalk'
+    :param rmsCalsection 计算rms的区间 TRMS和ARMS需要，时间单位s，比如：[1,20]
     :return:
     """
     paraDicts = {
@@ -96,7 +99,8 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
         "audioType":audioType,
         "aecStartPoint":aecStartPoint,
         "aecTargetType":aecTargetType,
-        'aecScenario':aecScenario
+        'aecScenario':aecScenario,
+        'rmsCalsection':rmsCalsection
     }
     comAuQUA = computeAudioQuality(**paraDicts)
     return methodcaller(metrics)(comAuQUA)
