@@ -2,6 +2,7 @@ import ctypes
 import sys
 from ctypes import *
 import os
+from formatConvert import wav2pcm
 
 
 class delaystruct(Structure):
@@ -28,7 +29,7 @@ def cal_delay(reffile, testfile, samplerate):
         return delays.Crude_DelayEst
 
 if __name__ == '__main__':
-       ref = r'E:\files\cle_malePolqaWB_8000.pcm'
-       test = r'E:\files\cle_malePolqaWB_8000_d.pcm'
-       cal_delay(ref,test,16000)
+       ref = r'D:\AutoWork\audiotestalgorithm\algorithmLib\SNR_ESTIMATION\speech.wav'
+       test = r'D:\AutoWork\audiotestalgorithm\algorithmLib\SNR_ESTIMATION\test.wav'
+       cal_delay(wav2pcm(ref),wav2pcm(test),16000)
        pass
\ No newline at end of file
